Struct cargo_lambda_interactive::list_option::ListOption
source · pub struct ListOption<T> {
pub index: usize,
pub value: T,
}Expand description
Represents a selection made by the user when prompted to select one or several options among those presented.
Fields
index: usizeIndex of the selected option relative to the original (full) list passed to the prompt.
value: TValue of the selected option.
Implementations
sourceimpl<T> ListOption<T>
impl<T> ListOption<T>
sourcepub fn new(index: usize, value: T) -> ListOption<T>
pub fn new(index: usize, value: T) -> ListOption<T>
sourcepub fn as_ref(&self) -> ListOption<&T>
pub fn as_ref(&self) -> ListOption<&T>
Converts from &ListOption<T> to ListOption<&T>.