Type Definition cargo_lambda_interactive::type_aliases::Suggester
source · pub type Suggester<'a> = &'a dyn Fn(&str) -> Result<Vec<String, Global>, Box<dyn Error + Send + Sync, Global>>;Expand description
Type alias to represent the function used to retrieve text input suggestions. The function receives the current input and should return a collection of strings containing the suggestions to be made to the user.