StyleSheet

Struct StyleSheet 

pub struct StyleSheet {
    pub fg: Option<Color>,
    pub bg: Option<Color>,
    pub att: Attributes,
}
Style definitions that can be applied to the rendered content.

Example

use inquire::ui::{Attributes, Color, StyleSheet};

let style_sheet = StyleSheet::default();

assert!(style_sheet.is_empty());

let style_sheet = style_sheet
    .with_bg(Color::DarkBlue)
    .with_attr(Attributes::ITALIC | Attributes::BOLD);

assert!(!style_sheet.is_empty());

Fields

fg: Option<Color>

Foreground color of text.

bg: Option<Color>

Background color of text.

att: Attributes

Attributes applied to text.

Implementations

Source

impl StyleSheet

pub fn new() -> StyleSheet

Creates a style sheet with no colors and no attributes

pub fn empty() -> StyleSheet

A stylesheet with no colors and no attributes.

pub fn is_empty(&self) -> bool

Check if the stylesheet contains no colors and no attributes.

pub fn with_fg(self, fg: Color) -> StyleSheet

Copies the StyleSheet to a new one set with the defined foreground Color.

pub fn with_bg(self, bg: Color) -> StyleSheet

Copies the StyleSheet to a new one set with the defined background Color.

pub fn with_attr(self, attributes: Attributes) -> StyleSheet

Copies the style sheet to a new one with the specified attributes.

Warning: this does not keep the previously applied attributes. If you want to just set a new attribute and keep the others, you need to apply the OR operation yourself.

Example
use inquire::ui::{Attributes, Color, StyleSheet};

let style_sheet = StyleSheet::default().with_attr(Attributes::BOLD);
assert_eq!(true,  style_sheet.att.contains(Attributes::BOLD));
assert_eq!(false, style_sheet.att.contains(Attributes::ITALIC));

let style_sheet = style_sheet.with_attr(Attributes::ITALIC);
assert_eq!(false, style_sheet.att.contains(Attributes::BOLD));
assert_eq!(true,  style_sheet.att.contains(Attributes::ITALIC));

let style_sheet = style_sheet.with_attr(style_sheet.att | Attributes::BOLD);
assert_eq!(true, style_sheet.att.contains(Attributes::BOLD));
assert_eq!(true, style_sheet.att.contains(Attributes::ITALIC));